summaryrefslogtreecommitdiff
path: root/fml/lib/FML/Restriction
diff options
context:
space:
mode:
authorfukachan <fukachan>2005-05-27 03:03:31 +0000
committerfukachan <fukachan>2005-05-27 03:03:31 +0000
commite6fc837dba963f236db29e3e38d62f215980d428 (patch)
tree33f8f9ab40c5862ddaa9e3711edaa8218026ce8b /fml/lib/FML/Restriction
parent1059e0cd170476595b06d3522d3a7915ae86e3be (diff)
downloadfml8-e6fc837dba963f236db29e3e38d62f215980d428.tar.gz
fml8-e6fc837dba963f236db29e3e38d62f215980d428.tar.bz2
fml8-e6fc837dba963f236db29e3e38d62f215980d428.zip
fix comments (FNF)
Diffstat (limited to 'fml/lib/FML/Restriction')
-rw-r--r--fml/lib/FML/Restriction/CGI.pm10
-rw-r--r--fml/lib/FML/Restriction/Post.pm17
2 files changed, 16 insertions, 11 deletions
diff --git a/fml/lib/FML/Restriction/CGI.pm b/fml/lib/FML/Restriction/CGI.pm
index 744c0df0..a44b07b4 100644
--- a/fml/lib/FML/Restriction/CGI.pm
+++ b/fml/lib/FML/Restriction/CGI.pm
@@ -1,9 +1,9 @@
#-*- perl -*-
#
-# Copyright (C) 2001,2002,2004 Ken'ichi Fukamachi
+# Copyright (C) 2001,2002,2004,2005 Ken'ichi Fukamachi
# All rights reserved.
#
-# $FML: CGI.pm,v 1.11 2004/01/21 03:40:43 fukachan Exp $
+# $FML: CGI.pm,v 1.12 2004/07/23 13:16:43 fukachan Exp $
#
package FML::Restriction::CGI;
@@ -53,7 +53,7 @@ my %cgi_methond =
-# Descriptions: return set of basic variable safe expressions as HASH_REF.
+# Descriptions: return a set of basic variable safe expressions as HASH_REF.
# Arguments: OBJ($self)
# Side Effects: none
# Return Value: HASH_REF
@@ -64,7 +64,7 @@ sub param_regexp
}
-# Descriptions: return set of method safe expressions as HASH_REF.
+# Descriptions: return a set of method safe expressions as HASH_REF.
# Arguments: OBJ($self)
# Side Effects: none
# Return Value: HASH_REF
@@ -122,7 +122,7 @@ Ken'ichi Fukamachi
=head1 COPYRIGHT
-Copyright (C) 2001,2002,2004 Ken'ichi Fukamachi
+Copyright (C) 2001,2002,2004,2005 Ken'ichi Fukamachi
All rights reserved. This program is free software; you can
redistribute it and/or modify it under the same terms as Perl itself.
diff --git a/fml/lib/FML/Restriction/Post.pm b/fml/lib/FML/Restriction/Post.pm
index e7804a5e..3dde1039 100644
--- a/fml/lib/FML/Restriction/Post.pm
+++ b/fml/lib/FML/Restriction/Post.pm
@@ -1,10 +1,10 @@
#-*- perl -*-
#
-# Copyright (C) 2003,2004 Ken'ichi Fukamachi
+# Copyright (C) 2003,2004,2005 Ken'ichi Fukamachi
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Post.pm,v 1.15 2004/11/14 11:18:23 fukachan Exp $
+# $FML: Post.pm,v 1.16 2004/12/05 16:19:13 fukachan Exp $
#
package FML::Restriction::Post;
@@ -98,9 +98,9 @@ sub permit_member_maps
my $curproc = $self->{ _curproc };
my $cred = $curproc->{ credential };
- # Q: the mail sender is a ML member?
+ # Q: the mail sender is an ML member?
if ($cred->is_member($sender)) {
- # A: Yes, we permit to distribute this article.
+ # A: Yes, we permit this article to distribute.
return("matched", "permit");
}
else {
@@ -147,10 +147,15 @@ sub reject
=head1 EXTENSION
+=head2 check_article_thread($rule, $sender)
+
+check references and permit post of this article if it refers this
+thread.
+
=cut
# Descriptions: check references and permit this message
# if it refers this thread.
# Arguments: OBJ($self) STR($rule) STR($sender)
# Side Effects: none
@@ -201,7 +206,7 @@ Ken'ichi Fukamachi
=head1 COPYRIGHT
-Copyright (C) 2003,2004 Ken'ichi Fukamachi
+Copyright (C) 2003,2004,2005 Ken'ichi Fukamachi
All rights reserved. This program is free software; you can
redistribute it and/or modify it under the same terms as Perl itself.
@@ -147,10 +147,15 @@ sub reject
=cut
-# Descriptions: check references and permit this message
+# Descriptions: check references and permit this article
# if it refers this thread.
# Arguments: OBJ($self) STR($rule) STR($sender)